@@ -6,7 +6,12 @@
 #'        It is a data matrix with cases corresponding to manuscripts and variables to Field Tag in the original SCOPUS and Thomson Reuters' ISI Web of Knowledge file.
 #' @param field is a character. It can be "article" or "author" to obtain frequency distribution of cited citations or cited authors (only first authors for ISI database) respectively. The default is \code{field = "article"}.
 #' @param sep is the field separator character. This character separates citations in each string of CR column of the bibiographic data frame. The default is \code{sep = ";"}.
-#' @return an object of \code{class} "table".
+#' @return an object of \code{class} "list"  containing the following components:
+#'
+#' \tabular{lll}{
+#' Cited \tab  \tab the most frequent cited manuscripts or authors\cr
+#' Year \tab       \tab the pubblication year (only for cited article analysis)\cr
+#' Source \tab      \tab the journal (only for cited article analysis)}
 #'
 #' 
 #'
@@ -17,7 +22,9 @@
 #'
 #' CR <- citations(scientometrics, field = "article", sep = ";")
 #'
-#' CR[1:10]
+#' CR$Cited[1:10]
+#' CR$Year[1:10]
+#' CR$Source[1:10]
 #'
 #' ## EXAMPLE 2: Cited first authors
 #' 
@@ -25,7 +32,7 @@
 #'
 #' CR <- citations(scientometrics, field = "author", sep = ";")
 #'
-#' CR[1:10]
+#' CR$Cited[1:10]
 #'
 #' @seealso \code{\link{biblioAnalysis}} function for bibliometric analysis.
 #' @seealso \code{\link{summary}} to obtain a summary of the results.
@@ -35,9 +42,14 @@
 
 citations <- function(M, field = "article", sep = ";"){
   CR=NULL
+  Year=NULL
+  SO=NULL
   
   if (field=="article"){
     listCR=strsplit(M$CR,sep)
+    listCR=lapply(listCR, function(l){
+      l=l[grep(",",l)]
+      })
   }
   
   if (field=="author"){
@@ -62,5 +74,18 @@ citations <- function(M, field = "article", sep = ";"){
   CR=CR[nchar(CR)>=3]
   CR=trim.leading(CR)
   CR=sort(table(CR),decreasing=TRUE)
+  if (field=="article"){
+    listCR=strsplit(rownames(CR),",")
+    Year=unlist(lapply(listCR, function(l){
+      if (length(l)>1){
+      l=suppressWarnings(as.numeric(l[2]))} else{l=NA}
+      }))
+    SO=unlist(lapply(listCR, function(l){
+      if (length(l)>2){
+      l=l[3]} else{l=NA}
+    }))
+    SO=trim.leading(SO)
+  }
+  CR=list(Cited=CR,Year=Year,Source=SO)
   return(CR)
 }
\ No newline at end of file
